@@ -114,15 +114,6 @@ async def _req_to_text(r):
         return (await r.read()).decode()
 
 
-def unjson(contents):
-    import ujson
-
-    try:
-        return ujson.loads(contents)
-    except:  # noqa: E722
-        return None
-
-
 class GCSFileSystem(AsyncFileSystem):
     r"""
     Connect to Google Cloud Storage.
@@ -555,7 +546,7 @@ class GCSFileSystem(AsyncFileSystem):
                 logger.exception("_call non-retriable exception: %s" % e)
                 raise e
         if json_out:
-            return unjson(contents)
+            return json.loads(contents)
         elif info_out:
             return info
         else:
@@ -799,7 +790,7 @@ class GCSFileSystem(AsyncFileSystem):
         bucket = bucket.rstrip("/")
         if "/" in bucket:
             return
-        await self._call("DELETE", "b/" + bucket, json_out=True)
+        await self._call("DELETE", "b/" + bucket, json_out=False)
         self.invalidate_cache(bucket)
         self.invalidate_cache("")
 
@@ -1301,7 +1292,7 @@ class GCSFileSystem(AsyncFileSystem):
             if hasattr(content, "decode"):
                 content = content.decode()
             try:
-                error = unjson(content)["error"]
+                error = json.loads(content)["error"]
                 msg = error["message"]
             except:  # noqa: E722
                 # TODO: limit to appropriate exceptions
